#
# spec file for package osc-plugin-collab
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2009 Vincent Untz <vuntz@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if %(if test -d %{_prefix}/lib/osc-plugins; then echo 1; else echo 0; fi)
%define oscplugindir %{_prefix}/lib/osc-plugins
%else
%define oscplugindir %{_localstatedir}/lib/osc-plugins
%endif
Name:           osc-plugin-collab
Version:        0.104+30
Release:        1.4
Summary:        Plugin to make collaboration easier with osc
License:        BSD-3-Clause
Group:          Development/Tools/Other
URL:            https://en.opensuse.org/openSUSE:Osc_Collab
Source0:        %{name}-%{version}.tar.xz
Source1:        sysuser-osc-collab.conf
# Needed for directory ownership
BuildRequires:  osc
BuildRequires:  sysuser-tools
Requires:       osc >= 0.165.0
# osc gnome was part of osc-plugins-gnome
Conflicts:      osc-plugins-gnome <= 0.4.26
BuildArch:      noarch
%if !(0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version} || 0%{?scientificlinux_version})
Recommends:     quilt
Recommends:     rpm-python3
Recommends:     xz
%else
Requires:       quilt
Requires:       rpm-python3
Requires:       xz
%endif

%description
This osc plugin extends osc with commands that makes it easier to use
the collaboration feature in the Build Service, and to keep up with
latest upstream versions.

%package -n osc-collab-server
Summary:        Server component for osc collab
Group:          Development/Tools/Other
Requires:       osc
Requires:       python3
Requires:       python3-feedparser
Requires:       python3-rpm
Requires:       python3-sgmllib3k
Requires:       python3-xml
Requires:       withlock
Requires:       user(osc-collab)

%description -n osc-collab-server
The server part of osc-plugin-collab, handles package reservations
and tracks in a database the various versions in devel projects, Factory
and upstream.

%package -n system-user-osc-collab
Summary:        System user for the osc-collab server component
Group:          System/Base
%sysusers_requires

%description -n system-user-osc-collab
System user for the osc-collab server component.

%prep
%autosetup

%build
%sysusers_generate_pre %{SOURCE1} sysuser-osc-collab

%install
install -D -m0644 osc-collab.py %{buildroot}%{oscplugindir}/osc-collab.py

mkdir -p %{buildroot}%{_sysusersdir}
install -m 644 %{SOURCE1} %{buildroot}%{_sysusersdir}/system-user-osc-collab.conf
install -d %{buildroot}%{_localstatedir}/lib/osc-collab
install -d %{buildroot}%{_datadir}/osc-collab-server
cp -r server %{buildroot}%{_datadir}/osc-collab-server

# Install default config file to /etc
mkdir -p %{buildroot}%{_sysconfdir}
mv %{buildroot}%{_datadir}/osc-collab-server/server/openSUSE-setup/collab-data/osc-collab.conf %{buildroot}%{_sysconfdir}

# Install run-scripts to /usr/lib/osc-collab-server
mkdir -p %{buildroot}%{_libexecdir}/osc-collab-server
mv %{buildroot}%{_datadir}/osc-collab-server/server/openSUSE-setup/cron-scripts/* %{buildroot}%{_libexecdir}/osc-collab-server

# And osc-collab-runner to /usr/bin
mkdir -p %{buildroot}%{_bindir}
mv %{buildroot}%{_datadir}/osc-collab-server/server/openSUSE-setup/osc-collab-runner %{buildroot}%{_bindir}

%pre -n system-user-osc-collab -f sysuser-osc-collab.pre

%files
%{oscplugindir}/osc-collab.py*

%files -n osc-collab-server
%attr(0700,osc-collab,root) %{_localstatedir}/lib/osc-collab
%{_datadir}/osc-collab-server
%{_bindir}/osc-collab-runner
%{_libexecdir}/osc-collab-server
%config %{_sysconfdir}/osc-collab.conf

%files -n system-user-osc-collab
%{_sysusersdir}/system-user-osc-collab.conf

%changelog
* Tue Nov  7 2023 dimstar@opensuse.org
- Update to version 0.104+30:
  * Fix definition of APIURL with newer osc
  * Track more base packages, mostly filesystem related
* Wed Feb 22 2023 dimstar@opensuse.org
- Update to version 0.104+26:
  * Re-implement filedir_to_pac as this was dropped in osc 1.0
* Tue Feb 21 2023 mcepl@suse.com
- Update to version 0.104+24:
  * No longer support being calles as 'osc gnome'
  * Track GNOME 41 for Leap 15.4 and SLE15SP4
* Tue Jan 11 2022 dimstar@opensuse.org
- Update to version 0.104+20:
  * osc-collab-runner: self-heal when runaway task is detected
  * openSUSE config: Track GNOME:Factory as GNOME Stable project
  * gnome-versions: arrive in 2022, where GNOME >= 40
* Tue Sep 28 2021 dimstar@opensuse.org
- Update to version 0.104+17:
  * [upstream] track some more gnome packages
* Wed Sep  1 2021 dimstar@opensuse.org
- Update to version 0.104+15:
  * [upstream] track some more gnome packages
* Fri May 14 2021 dimstar@opensuse.org
- Update to version 0.104+14:
  * obs-db/upstream: range expects an int value
  * No longer try to download GNOME 3.12 data - EOL
  * Upstream: track gnome-tour (new in GNOME 40)
* Tue Feb  9 2021 dimstar@opensuse.org
- Update to version 0.104+11:
  * osc-collab: Do not crash if we encounter a (broken) package (version unknown)
  * gnome-versions: fix crash in new GNOME version scheme code
* Fri Jan 15 2021 dimstar@opensuse.org
- Update to version 0.104+9:
  * upstream: Follow GNOME's new versioning scheme
  * client: fix crash in case the parent version could not be identified
* Fri Jan 15 2021 dimstar@opensuse.org
- Update to version 0.104+7:
  * gnome-version: use rpm.labelCompare to compare version numbers
  * gnome-versions: ignore ../ directory
* Fri Jan 15 2021 dimstar@opensuse.org
- Update to version 0.104+5:
  * gnome-versions: fix extraction of versions with new gdo UI
* Fri Jan 15 2021 dimstar@opensuse.org
- Update to version 0.104+4:
  * gnome-versions: sync up with latest download.gnome.org UI
* Mon Jul 13 2020 dimstar@opensuse.org
- Update to version 0.104+3:
  * gnome-updates: upstream no longer tracks a -stable.config
  * gnome-versions: fix typo
* Mon Feb 24 2020 dimstar@opensuse.org
- Update to version 0.104+1:
  * Cleanup TMPDIR at the end of collecting GNOME versions
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 0.104:
  * upstream-packages-match.txt: GTK+ was renamed to GTK
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 0.103+13:
  * run-upstream: remove debug print
  * No longer track legacy openSUSE releases < Leap 15.2
  * Track GNOME:STABLE:3.34
  * Add main runner
  * Prepare for better pkg installation
  * run-gnome-versions: adjust cache path in line with the rest of the tool
  * run-updategit: not needed: this is now properly packaged
  * Add gnome-upstream version tooling
  * Convert upstream scripts to python3
  * buildservice: use osc to download stuff
  * Auto-convert obs-db to python3 by 2to3
  * Update default configuration for openSUSE installation (based on package)
* Mon Feb 10 2020 dimstar@opensuse.org
- Switch to use _source service:
  + We need the entire git tree, as newly we also produce server
    packages. This is possibly less interesting for the masses, but
    the openSUSE infrastructure will use this package.
* Sun Oct  6 2019 vuntz@opensuse.org
- Update to version 0.103:
  + Call time.tzset() after changing the timezone (#53)
  + Fix python2 compatibility (#49)
- Fix packaging for new versions of Fedora that don't include
  .pyc/.pyo files
* Wed Sep 11 2019 vuntz@opensuse.org
- Update to version 0.102:
  + Fix configuring on python3
  + Fix another str vs. bytes issue
* Fri May  3 2019 vuntz@opensuse.org
- Update to version 0.101:
  + Port to python3
  + Use https on the server
* Thu Mar 21 2019 vuntz@opensuse.org
- Update to version 0.100:
  + Support new location for oscrc in ~/.config/osc/
* Sat Nov 18 2017 zaitor@opensuse.org
- Update to version 0.99:
  + Support diff in meson buildsystem based packages.
* Sun Jul 21 2013 vuntz@opensuse.org
- Update to version 0.98:
  + Really port plugin to osc >= 0.140.1
  + Remove compatibility code with very old versions of osc
- Update Requires on osc to be versioned, since this now really
  only works with a recent version of osc.
* Mon Jul  1 2013 vuntz@opensuse.org
- Update to version 0.97:
  + Adapt code to osc's new plugin mechanism
* Thu Jan 10 2013 vuntz@opensuse.org
- Make build noarch.
- Fix build on Fedora/RHEL/CentOS/ScientificLinux:
  + Use Requires instead of Recommends since there are no
    Recommends there.
  + Package .pyc/.pyo files following the Fedora packaging policy
    (except for ScientificLinux, which doesn't do that).
* Mon Jan  7 2013 vuntz@opensuse.org
- Update to version 0.96:
  + Use new collab server.
* Thu Feb 23 2012 vuntz@opensuse.org
- Update to version 0.95:
  + Features:
  - Add ugly workaround to extract files from .tar.xz tarballs
  - Extract a diff of old and new configure.{ac,in} on update
  - Supersede old requests on buildsubmit/forward (unless
  - -no-supersede is used)
  + Fixes:
  - List requests that are in state 'review'
  - Improve todo performance
  - Use a cache when listing requests to improve performance
  - Fix crash in todo for packages with no upstream version
  - Use UTC for timezone in .changes entries
  - Change forwarded request description to the one from webui
  - Reset Release tag to 0 instead of 1 on updates
- Add Recommends for xz, so we can extract files from .tar.xz
  tarballs.
* Thu Jun 30 2011 vuntz@opensuse.org
- Update to version 0.94:
  + Features:
  - Add comments:
    . new 'comment', 'commentset', 'commentunset',
    'listcommented' commands to edit/view comments on packages
    . make 'todo' display packages with a comment, and add
  - -ignore-comments and --exclude-commented options to
    control this behavior
    . display comments after 'setup'/'update', unless
  - -ignore-comments is used
  - Add --details/--no-details options and collab_details config
    option (default to False) to display more details in 'todo'
  - 'update' command improvements:
    . Stop recompressing tarballs
    . Update Source tag in .spec on update to the tarball URL
    . Drop the "(Version XYZ)" part of the .spec header
  - Add --nobranch option to 'setup'/'update' commands
  - Unreserve the package after successful 'buildsubmit'
  - Add collab_do_package_tracking config option (default to
    False)
  + Fixes:
  - Make 'isreserved' work with multiple packages
* Tue Jun 28 2011 vuntz@opensuse.org
- Add quilt Recommends, as the plugin tells the user to use quilt
  to check patches.
- Update Url tag to point to new wiki page.
* Mon May 30 2011 vuntz@opensuse.org
- Update to version 0.93:
  + Fixes:
  - Handle httplib.BadStatusLine exception in build
  - Fix bug that was creating inconsistent state in checkout
* Fri Sep 10 2010 vuntz@opensuse.org
- Update to version 0.92:
  + Fixes:
  - Do not create empty helper files for NEWS/ChangeLog
  - Use updated build state names from OBS ('signing' was added,
    'expansion error' was renamed to 'unresolved')
  - Fix crash when list of reserved packages cannot be fetched
  - Make "osc collab forward" work with osc 0.129
* Sun Jan 17 2010 vuntz@opensuse.org
- Update to version 0.91:
  + Features:
  - Use the new scheduler state for build/buildsubmit to
    determine if the build status can be trusted or not.
  + Fixes:
  - Fix addition of osc-collab.* files to exclude glob.
* Mon Sep 14 2009 vuntz@opensuse.org
- This is the old osc-gnome plugin, split from osc-plugins-gnome,
  and renamed to osc-collab.
- Update to version 0.90:
  + Features:
  - Rename to osc collab and do not refer to anything GNOME
    specific anywhere
  - Support delta in non-link packages
  - Remove potential trailing slash from packages passed as args
    for convenience when used with autocompletion
  - Make the config options work per apiurl
  - Make it possible to use more than one repo at the same time
  - Display against which repo the build is done
  - Make setup/update branch from the devel project
  - Take into account the version in devel project for
    todo/update
  - Use openSUSE:Factory by default instead of GNOME:Factory
  - Autodetect default repository for builds
  - Add --nodevelproject option for the relevant commands
  - Add --version command
  + Fixes:
  - Improve upstream tarball basename detection in when the
    basename of the upstream tarball is not in the URL, but in
    the query fields
  - Fix warning about tag in Source always appearing
  - Do not crash with osc from trunk
  - Better handling of update when package is already updated
  - Fix listreserved to not list reservations from all projects
  - Substitute macros in %%define lines too
  - Remove old cache files
  - Fix parsing of empty list options in ~/.oscrc
  - Improve help message
  - Code cleanups
